package cd.casic.ci.common.pipeline.pojo.agent;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.assertj.core.util.Lists;

import java.util.List;

/**
 * @author by mianbin
 * @Classname NewHeartbeatInfo
 * @Description TODO
 * @Date 2025/4/8 19:31
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Schema(name = "心跳信息模型")
public class NewHeartbeatInfo {
    @Schema(description = "主版本")
    private String masterVersion;
    @Schema(description = "从属版本")
    private String slaveVersion;
    @Schema(description = "主机名")
    private String hostName;
    @Schema(description = "构建机模型")
    private String agentIp;
    @Schema(description = "并行任务计数")
    private int parallelTaskCount;
    @Schema(description = "构建机安装路径")
    private String agentInstallPath;
    @Schema(description = "启动者")
    private String startedUser;
    @Schema(description = "第三方构建信息列表")
    private List<ThirdPartyBuildInfo> taskList;
    @Schema(description = "Agent属性信息")
    private AgentPropsInfo props;
    @Schema(description = "构建机id")
    private Long agentId;
    @Schema(description = "项目id")
    private String projectId;
    @Schema(description = "心跳时间戳")
    private Long heartbeatTime;
    @Schema(description = "忙碌运行中任务数量")
    @Builder.Default
    private int busyTaskSize = 0;
    @Schema(description = "docker并行任务计数")
    private Integer dockerParallelTaskCount;
    @Schema(description = "docker构建信息列表")
    private List<ThirdPartyDockerBuildInfo> dockerTaskList;
    @Schema(description = "忙碌运行docker中任务数量")
    @Builder.Default
    private int dockerBusyTaskSize = 0;
    @Schema(description = "Agent退出的错误信息")
    private AgentErrorExitData errorExitData;

    public static NewHeartbeatInfo dummyHeartbeat(String projectId, Long agentId) {
        return NewHeartbeatInfo.builder()
                .masterVersion("")
                .slaveVersion("")
                .hostName("")
                .agentIp("")
                .parallelTaskCount(0)
                .agentInstallPath("")
                .startedUser("")
                .taskList(Lists.emptyList())
                .props(new AgentPropsInfo("", null, null))
                .agentId(agentId)
                .projectId(projectId)
                .heartbeatTime(System.currentTimeMillis())
                .dockerParallelTaskCount(0)
                .dockerTaskList(List.of())
                .build();
    }
}
