package cd.casic.ci.common.pipeline.pojo.element.trigger;

import cd.casic.ci.common.pipeline.enums.StartType;
import cd.casic.ci.common.pipeline.enums.TriggerRepositoryType;
import cd.casic.ci.common.pipeline.pojo.element.Element;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.experimental.Accessors;

import java.util.Arrays;
import java.util.List;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.element.trigger
 * @Project：ops-pro
 * @name：TimerTriggerElement
 * @Date：2025/03/27 10:00
 * @Filename：TimerTriggerElement
 * @description：Todo
 */
@Accessors(chain = true)
@Schema(title = "定时触发")
public class TimerTriggerElement extends Element {
    public static final String classType = "timerTrigger";

    @Schema(title = "任务名称", required = true)
    private String name = "定时触发";

    @Schema(title = "id", required = false)
    private String id;

    @Schema(title = "状态", required = false)
    private String status;

    @Schema(title = "定时表达式", required = false)
    @Deprecated
    private String expression;

    @Schema(title = "改进后的表达式", required = false)
    private List<String> newExpression;

    @Schema(title = "高级定时表达式", required = false)
    private List<String> advanceExpression;

    @Schema(title = "源代码未更新则不触发构建", required = false)
    private Boolean noScm;

    @Schema(title = "指定代码库分支", required = false)
    private List<String> branches;

    @Schema(title = "代码库类型", required = false)
    private TriggerRepositoryType repositoryType;

    @Schema(title = "代码库HashId", required = false)
    private String repoHashId;

    @Schema(title = "指定代码库别名", required = false)
    private String repoName;

    @Override
    public String getClassType() {
        return classType;
    }

    private boolean isOldExpress() {
        return (newExpression == null || newExpression.isEmpty()) &&
                (advanceExpression == null || advanceExpression.isEmpty());
    }

    private String checkAndSetSecond(String expression) {
        String trimmedExpression = expression.trim();
        String[] expressionParts = trimmedExpression.split(" ");
        if (!"0".equals(expressionParts[0])) {
            List<String> newExpressionParts = Arrays.asList(expressionParts);
            newExpressionParts.set(0, "0");
            return String.join(" ", newExpressionParts);
        }
        return trimmedExpression;
    }

    @Override
    public String findFirstTaskIdByStartType(StartType startType) {
        return StartType.TIME_TRIGGER.name().equals(startType.name()) ? this.id : super.findFirstTaskIdByStartType(startType);
    }

    public boolean enableRepoConfig() {
        return TriggerRepositoryType.SELF.equals(repositoryType) ||
                (TriggerRepositoryType.ID.equals(repositoryType) && repoHashId != null && !repoHashId.isBlank()) ||
                (TriggerRepositoryType.NAME.equals(repositoryType) && repoName != null && !repoName.isBlank());
    }
}
