package cd.casic.pipeline.dispatch.api;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.dispatch.pojo.enums.JobQuotaVmType;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;


@Tag(name = "BUILD_JOBS_PROJECT_QUOTA", description = "Job配额管理")
@RestController
@RequestMapping("/service/quotas/running")
public interface ServiceJobQuotaBusinessResource {

    @Operation(summary = "上报一个JOB启动")
    @PostMapping("/job/projects/{projectId}/vmTypes/{vmType}/builds/{buildId}/vmSeqs/{vmSeqId}")
    CommonResult<Boolean> checkAndAddRunningJob(
            @Parameter(description = "projectId", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "vmType", required = true)
            @PathVariable("vmType") JobQuotaVmType vmType,
            @Parameter(description = "buildId", required = true)
            @PathVariable("buildId") String buildId,
            @Parameter(description = "vmSeqId", required = true)
            @PathVariable("vmSeqId") String vmSeqId,
            @Parameter(description = "executeCount", required = true)
            @RequestParam("executeCount") Integer executeCount,
            @Parameter(description = "containerId", required = true)
            @RequestParam("containerId") String containerId,
            @Parameter(description = "containerHashId", required = false)
            @RequestParam("containerHashId") String containerHashId,
            @Parameter(description = "channelCode", required = false)
            @RequestParam("channelCode") String channelCode
    );

    @Operation(summary = "上报一个JOB结束")
    @DeleteMapping("/job/projects/{projectId}/pipelines/{pipelineId}/builds/{buildId}/vmSeqs/{vmSeqId}")
    CommonResult<Boolean> removeRunningJob(
            @Parameter(description = "projectId", required = true)
            @PathVariable("projectId") String projectId,
            @Parameter(description = "pipelineId", required = true)
            @PathVariable("pipelineId") String pipelineId,
            @Parameter(description = "buildId", required = true)
            @PathVariable("buildId") String buildId,
            @Parameter(description = "vmSeqId", required = false)
            @PathVariable("vmSeqId") String vmSeqId,
            @Parameter(description = "executeCount", required = true)
            @RequestParam("executeCount") Integer executeCount
    );
}