package cd.casic.ci.log.dal.dao;

import cd.casic.framework.mybatis.core.mapper.BaseMapperX;
import cd.casic.ci.log.dal.dataobject.LogIndicesV2;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.apache.ibatis.annotations.Mapper;

import java.util.Date;
import java.util.Objects;

/**
 * @author by mianbin
 * @Classname IndexDao
 * @Description LogIndicesV2 的mapper
 * @Date 2025/3/20 10:07
 */
@Mapper
public interface IndexMapper extends BaseMapperX<LogIndicesV2> {
    default void create(String buildId, String indexName, boolean enable) {
        Date now = new Date();
        LogIndicesV2 entity = new LogIndicesV2(buildId, indexName, 1, now, now, enable, true);
        insert(entity);
    }

    /**
     * 通过 id 查找 LogIndicesV2
     * 该方法是可能返回 null 值的，所以调用该方法的时候都应该对 null 值进行判断
     *
     * @param buildId
     * @return
     */
    default LogIndicesV2 getBuild(String buildId) {
        return selectOne(Wrappers.<LogIndicesV2>lambdaQuery().eq(LogIndicesV2::getBuildId, buildId));
    }

    default String getIndexName(String buildId) {
        LogIndicesV2 logIndices = getBuild(buildId);
        if (logIndices == null)
            return "";
        return logIndices.getIndexName();
    }

    default boolean updateLastLineNum(String buildId, long latestLineNum) {
        LogIndicesV2 logIndicesV2 = selectOne(LogIndicesV2::getBuildId, buildId);
        if (Objects.nonNull(logIndicesV2)) {
            logIndicesV2.setLastLineNum(latestLineNum);
        }
        return insertOrUpdate(logIndicesV2);
    }
}
