package cd.casic.ci.process.api.process.pojo.pipeline;

import cd.casic.ci.common.pipeline.Model;
import cd.casic.ci.common.pipeline.enums.BranchVersionAction;
import cd.casic.ci.common.pipeline.enums.VersionStatus;
import cd.casic.ci.process.api.process.pojo.setting.PipelineVersionSimple;
import cd.casic.ci.process.api.process.utils.PipelineVersionUtils;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;

import java.time.LocalDateTime;

/**
 * @author by mianbin
 * @Classname PipelineResourceVersion
 * @Description TODO
 * @Date 2025/3/31 17:40
 */
@Data
@AllArgsConstructor
@Schema(title = "流水线版本-详细内容")
public class PipelineResourceVersion {
    @Schema(title = "项目ID", required = true)
    private String projectId;
    @Schema(title = "流水线ID", required = true)
    private String pipelineId;
    @Schema(title = "记录版本号", required = true)
    private int version;
    @Schema(title = "JSON编排内容（POJO）", required = true)
    private Model model;
    @Schema(title = "YAML编排内容", required = false)
    private String yaml;
    @Schema(title = "YAML编排版本", required = false)
    private String yamlVersion;
    @Schema(title = "版本名称", required = true)
    private String versionName;
    @Schema(title = "创建者", required = true)
    private String creator;
    @Schema(title = "版本创建时间", required = true)
    private LocalDateTime createTime;
    @Schema(title = "更新操作人", required = true)
    private String updater;
    @Schema(title = "版本修改时间", required = true)
    private LocalDateTime updateTime;
    @Schema(title = "发布版本号", required = false)
    private Integer versionNum;
    @Schema(title = "编排版本号", required = false)
    private Integer pipelineVersion;
    @Schema(title = "触发器版本号", required = false)
    private Integer triggerVersion;
    @Schema(title = "设置版本号", required = false)
    private Integer settingVersion;
    @Schema(title = "是否还有构建记录引用该版本标识", required = false)
    private Boolean referFlag;
    @Schema(title = "关联构建记录总数", required = false)
    private Integer referCount;
    @Schema(title = "草稿版本标识", required = false)
    private VersionStatus status;
    @Schema(title = "分支版本状态", required = false)
    private BranchVersionAction branchAction;
    @Schema(title = "版本变更说明", required = false)
    private String description;
    @Schema(title = "调试构建ID", required = false)
    private String debugBuildId;
    @Schema(title = "该版本的来源版本（空时一定为主路径）", required = false)
    private Integer baseVersion;

    public PipelineVersionSimple toSimple() {
        return new PipelineVersionSimple(
                pipelineId,
                creator,
                createTime,
                updater,
                updateTime != null ? updateTime : null,
                version,
                versionName != null ? versionName : PipelineVersionUtils.getVersionName(
                        versionNum != null ? versionNum : version,
                        versionNum != null ? versionNum : version,
                        0,
                        0
                ),
                referFlag,
                referCount,
                versionNum,
                pipelineVersion,
                triggerVersion,
                settingVersion,
                status != null ? status : VersionStatus.RELEASED,
                debugBuildId,
                baseVersion,
                description,
                yamlVersion
        );
    }
}
