package cd.casic.ci.log.scm.service.impl;


import cd.casic.ci.log.scm.dal.pojo.Repository;
import cd.casic.framework.commons.exception.ServiceException;
import cd.casic.framework.commons.dataobject.BaseDO;
import cd.casic.ci.log.scm.dal.dao.RepositoryRecordMapper;
import cd.casic.ci.log.scm.dal.dto.RepositoryRecord;
import cd.casic.ci.log.scm.enums.RepositoryConfig;
import cd.casic.ci.log.scm.enums.RepositoryType;
import cd.casic.ci.log.scm.service.CodeRepositoryServiceRegistrar;
import cd.casic.ci.log.scm.service.code.CodeRepositoryService;
import cd.casic.ci.log.scm.utils.HashUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

@Service
@Slf4j
public class RepositoryServiceImpl {

    @Resource
    private RepositoryRecordMapper repositoryRecordMapper;


    public Repository serviceGet(String projectId, RepositoryConfig repositoryConfig) {
        return compose(getRepository(projectId, repositoryConfig));
    }

    private Repository compose(RepositoryRecord repository) {
        CodeRepositoryService<?> codeRepositoryService = CodeRepositoryServiceRegistrar.getServiceByScmType(repository.getType());
        return codeRepositoryService.compose(repository);
    }

    private RepositoryRecord getRepository(String projectId, RepositoryConfig repositoryConfig) {
        log.info("[{}Start to get the repository - ({})]", projectId, repositoryConfig);
        if (repositoryConfig.getRepositoryType() == RepositoryType.ID) {
            long repositoryId = HashUtil.decodeOtherIdToLong(repositoryConfig.getRepositoryId());
            LambdaQueryWrapper<RepositoryRecord> eq = Wrappers.<RepositoryRecord>lambdaQuery()
                    .eq(RepositoryRecord::getId, repositoryId)
                    .eq(StringUtils.isNoneBlank(projectId), RepositoryRecord::getProjectId, projectId)
                    .eq(BaseDO::getDeleted, false);
            RepositoryRecord repositoryRecord = repositoryRecordMapper.selectOne(eq);
            if (repositoryRecord == null) {
                throw new ServiceException(-1000, "not found");
            }
            return repositoryRecord;
        } else if (repositoryConfig.getRepositoryType() == RepositoryType.NAME) {
            LambdaQueryWrapper<RepositoryRecord> eq = Wrappers.<RepositoryRecord>lambdaQuery()
                    .eq(RepositoryRecord::getAliasName, repositoryConfig.getRepositoryId())
                    .eq(RepositoryRecord::getProjectId, projectId)
                    .eq(BaseDO::getDeleted, false);
            RepositoryRecord repositoryRecord = repositoryRecordMapper.selectOne(eq);
            if (repositoryRecord == null) {
                throw new ServiceException(-1000, "not found");
            }
            return repositoryRecord;
        }
        return null;
    }
}
