package cd.casic.pipeline.store.api.common;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.store.pojo.common.classify.Classify;
import cd.casic.pipeline.store.pojo.common.enums.ErrorCodeTypeEnum;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import cd.casic.pipeline.store.pojo.common.publication.StoreBuildResultRequest;
import cd.casic.pipeline.store.pojo.common.sensitive.SensitiveConfResp;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "SERVICE_STORE", description = "service-store")
@RestController
@RequestMapping("/service/store")
public interface ServiceStoreResource {

    @Operation(summary = "卸载")
    @DeleteMapping("/codes/{storeCode}/uninstall")
    CommonResult<Boolean> uninstall(
            @Parameter(description = "标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "类型", required = true)
            @RequestParam("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "项目", required = true)
            @RequestParam("projectCode")
            String projectCode
    );

    @Operation(summary = "获取敏感数据")
    @GetMapping("/getSensitiveConf")
    CommonResult<List<SensitiveConfResp>> getSensitiveConf(
            @Parameter(description = "组件类型", required = true)
            @RequestParam("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "组件标识", required = true)
            @RequestParam("storeCode")
            String storeCode
    );

    @Operation(summary = "store组件内置流水线构建结果处理")
    @PutMapping("/pipelineIds/{pipelineId}/buildIds/{buildId}/build/handle")
    CommonResult<Boolean> handleStoreBuildCommonResult(
            @Parameter(description = "流水线ID", required = true)
            @PathVariable("pipelineId")
            String pipelineId,
            @Parameter(description = "构建ID", required = true)
            @PathVariable("buildId")
            String buildId,
            @Parameter(description = "store组件内置流水线构建结果请求报文体", required = true)
            StoreBuildResultRequest storeBuildCommonResultRequest
    );

    @Operation(summary = "判断用户是否是该组件的成员")
    @GetMapping("/codes/{storeCode}/user/validate")
    CommonResult<Boolean> isStoreMember(
            @Parameter(description = "标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "类型", required = true)
            @RequestParam("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "用户ID", required = true)
            @RequestParam("userId")
            String userId
    );

    @Operation(summary = "判断项目是否是研发商店公共项目")
    @GetMapping("projects/{projectCode}/validate")
    CommonResult<Boolean> isPublicProject(
            @Parameter(description = "标识", required = true)
            @PathVariable("projectCode")
            String projectCode
    );

    @Operation(summary = "校验流水线用户访问组件信息权限")
    @GetMapping("/codes/{storeCode}/pipeline/visit/validate")
    CommonResult<Boolean> validatePipelineUserStorePermission(
            @Parameter(description = "标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "类型", required = true)
            @RequestParam("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "用户ID", required = true)
            @RequestParam("userId")
            String userId
    );

    @Operation(summary = "判断错误码是否合规")
    @PostMapping("/codes/{storeCode}/errorCode/compliance")
    CommonResult<Boolean> isComplianceErrorCode(
            @Parameter(description = "标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "类型", required = true)
            @RequestParam("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "错误码", required = true)
            @RequestParam("errorCode")
            int errorCode,
            @Parameter(description = "错误码类型", required = true)
            @RequestParam("errorCodeType")
            ErrorCodeTypeEnum errorCodeType
    );

    @GetMapping("/types/{storeType}/codes/{storeCode}/versions/{version}/permission/validate")
    @Operation(summary = "校验是否有使用该组件的权限")
    CommonResult<Boolean> validateComponentDownloadPermission(
            @Parameter(description = "标识", required = true)
            @PathVariable("storeCode")
            String storeCode,
            @Parameter(description = "类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "版本号", required = true)
            @PathVariable("version")
            String version,
            @Parameter(description = "项目", required = true)
            @RequestParam("projectCode")
            String projectCode,
            @Parameter(description = "用户ID", required = true)
            @RequestParam("userId")
            String userId
    );

    @Operation(summary = "获取组件分类信息列表")
    @GetMapping("/classifies/types/{storeType}/list")
    CommonResult<List<Classify>> getClassifyList(
            @Parameter(description = "组件类型", required = true)
            @PathVariable("storeType")
            StoreTypeEnum storeType
    );
}